<?php

/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

// Settings for the app.
// Copy to settings.php and customize.

$SETTINGS = [
    // Whether to output debugging info like PHP notices, warnings,
    // and stacktraces.
    // Turning this on in production is a security risk and can sometimes break
    // things, such as JSON output where extra content is not expected.
    "debug" => true,
    // Database connection settings
    // See http://medoo.in/api/new for info
    "database" => [
        "type" => "mysql",
        "name" => "machinemanager",
        "server" => "localhost",
        "user" => "app",
        "password" => "",
        "charset" => "utf8"
    ],
    "apis" => [
        "invoiceninja" => [
            "url" => "https://app.invoiceninja.com/api/v1",
            "token" => ""
        ]
    ],
    // Name of the app.
    "site_title" => "MachineManager",
    "branding" => [
        // Title of public tracking page
        "publictitle" => "Device Lookup",
        // Shown in public tracking page
        "machineidnumber" => "Netsyms device ID number, machine ID number",
        // Shown in public tracking page
        "shortmachineid" => "Device/Machine ID Number"
    ],
    "labels" => [
        // The following keys/values are made available to gLabels during template rendering.
        "fields" => [
            // Shown above machine ID barcodes on labels (key ${idnumbertitle})
            "idnumbertitle" => "Netsyms Device ID #",
            // Rendered to QR codes on labels (key ${link})
            "link" => "https://qr.ntsm.io/?t=mid&q={{id}}",
            // Rendered on labels (key ${linktitle_lg})
            "linktitle_lg" => "Scan QR code or visit ntsm.io/pci for device\ninfo and tracking",
            // Rendered on labels (key ${linktitle_sm})
            "linktitle_sm" => "Scan QR code or visit ntsm.io/pci for device info and tracking",
            // Rendered on labels (key ${linktitle_xl})
            "linktitle_xl" => "You can check the status of your device by scanning the QR code, or by going to ntsm.io/pci and entering the Netsyms Device ID.",
            // Rendered on labels (key ${companyname})
            "companyname" => "Netsyms Technologies",
            // Rendered on labels (key ${companyphone})
            "companyphone" => "(406) 404-7177",
            // Rendered on labels (key ${companywebsite})
            "companywebsite" => "netsyms.com"
        ],
        // print/templates/$key.glabels => visible template/label title
        "templates" => [
            "machineid" => "ID Label",
            "machineidanonymous" => "ID Label (No \"Property Of\")",
            "machineidinternal" => "Internal ID Label",
            "machineidlarge" => "Large ID Label",
            "doortag" => "Door Tag",
            "pickupslip" => "Pickup Slip"
        ]
    ],
    // Settings for connecting to the AccountHub server.
    "accounthub" => [
        // URL for the API endpoint
        "api" => "http://localhost/accounthub/api/",
        // URL of the home page
        "home" => "http://localhost/accounthub/home.php",
        // API key
        "key" => "123"
    ],
    // List of required user permissions to access this app.
    "permissions" => [
    ],
    // List of permissions required for API access. Remove to use the value of
    // "permissions" instead.
    "api_permissions" => [
    ],
    // For supported values, see http://php.net/manual/en/timezones.php
    "timezone" => "America/Denver",
    "datetime_format" => "M j Y g:ia",
    "date_format" => "M j Y",
    // Language to use for localization. See langs folder to add a language.
    "language" => "en",
    // Shown in the footer of all the pages.
    "footer_text" => "",
    // Also shown in the footer, but with "Copyright <current_year>" in front.
    "copyright" => "Netsyms Technologies",
    // Base URL for building links relative to the location of the app.
    // Only used when there's no good context for the path.
    // The default is almost definitely fine.
    "url" => "."
];
